import type { Handle } from '@sveltejs/kit';
import type { AnyRouter } from '@trpc/server';
import { CreateContextFn, ResponseMetaFn } from './types';
/**
 * A function that creates a tRPC handle.
 * @see https://kit.svelte.dev/docs/hooks
 */
export declare function createTRPCHandle<Router extends AnyRouter>({ url, router, createContext, responseMeta, }: {
    /**
     * The URL prefix of tRPC routes.
     * Must start with `/` and NOT end with `/`.
     * Requests starting with this prefix will be intercepted and handled by tRPC,
     * and will NOT be forwarded to SvelteKit.
     * @default '/trpc' */
    url?: string;
    /**
     * The tRPC router
     * @see https://trpc.io/docs/router */
    router: Router;
    /**
     * A function called for each request, whose result is propagated to all resolvers.
     * You can use this to pass contextual data down to the resolvers.
     * @see https://trpc.io/docs/context */
    createContext?: CreateContextFn<Router>;
    /**
     * A function allowing you to override/customize the response status and headers
     * (i.e. to control caching).
     * @see https://trpc.io/docs/caching */
    responseMeta?: ResponseMetaFn<Router>;
}): Handle;
